@@ -9,7 +9,6 @@
 #include <QTest>
 #include <QObject>
 #include <QDateTime>
-#include <QDebug>
 
 using namespace KMime;
 
@@ -24,10 +23,10 @@ private Q_SLOTS:
 
         auto dt = QDateTime::currentDateTime();
         dt.setTime(QTime(12, 34, 56));
-        QCOMPARE(f.dateString(dt), QString::fromLatin1("Today 12:34:56"));
+        QCOMPARE(f.dateString(dt), QLatin1String("Today 12:34 PM"));
 
         dt.setDate(dt.date().addDays(-1));
-        QCOMPARE(f.dateString(dt), QString::fromLatin1("Yesterday 12:34:56"));
+        QCOMPARE(f.dateString(dt), QLatin1String("Yesterday 12:34 PM"));
 
         dt.setDate(dt.date().addDays(-1));
         QVERIFY(f.dateString(dt).startsWith(QLocale::c().toString(dt, QLatin1String("dddd"))));
