@@ -28,10 +28,12 @@
 #include "kmime_parsers.h"
 #include "kmime_util_p.h"
 
-#include <KCharsets>
 #include <KCodecs>
 
-
+#include <QDebug>
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+#include <QStringDecoder>
+#endif
 #include <QTextCodec>
 
 using namespace KMime;
@@ -367,16 +369,25 @@ QString Content::decodedText(bool trimText, bool removeTrailingNewlines)
       return {};
     }
 
-    bool ok = true;
-    QTextCodec *codec =
-        KCharsets::charsets()->codecForName(QLatin1String(contentType()->charset()), ok);
-    if (!ok  || codec == nullptr) {   // no suitable codec found => try local settings and hope the best ;-)
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    QTextCodec *codec = QTextCodec::codecForName(contentType()->charset());
+    if (codec == nullptr) {   // no suitable codec found => try local settings and hope the best ;-)
         codec = QTextCodec::codecForLocale();
         QByteArray chset = codec->name();
         contentType()->setCharset(chset);
     }
 
     QString s = codec->toUnicode(d_ptr->body.data(), d_ptr->body.length());
+#else
+    QStringDecoder codec(contentType()->charset().constData());
+    if (!codec.isValid()) {   // no suitable codec found => try local settings and hope the best ;-)
+        codec = QStringDecoder(QStringDecoder::System);
+        QByteArray chset = codec.name();
+        contentType()->setCharset(chset);
+    }
+
+    QString s = codec.decode(d_ptr->body);
+#endif
 
     if (trimText || removeTrailingNewlines) {
         int i;
@@ -403,11 +414,9 @@ QString Content::decodedText(bool trimText, bool removeTrailingNewlines)
 
 void Content::fromUnicodeString(const QString &s)
 {
-    bool ok = true;
-    QTextCodec *codec =
-        KCharsets::charsets()->codecForName(QLatin1String(contentType()->charset()), ok);
+    QTextCodec *codec = QTextCodec::codecForName(contentType()->charset());
 
-    if (!ok) {   // no suitable codec found => try local settings and hope the best ;-)
+    if (!codec) {   // no suitable codec found => try local settings and hope the best ;-)
         codec = QTextCodec::codecForLocale();
         QByteArray chset = codec->name();
         contentType()->setCharset(chset);
